==> jc-1.4.0.tar.gz: soot/FastHierarchy__24Interval.h <==
// public class soot.FastHierarchy$Interval

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f9bd31f9535d22c1 soot_FastHierarchy__24Interval

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_FastHierarchy__24Interval_H_
#define _JC_soot_FastHierarchy__24Interval_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_FastHierarchy$object;
struct _jc_soot_FastHierarchy__24Interval$object;

// Typedefs
typedef struct _jc_soot_FastHierarchy__24Interval$sub_refs	_jc_soot_FastHierarchy__24Interval$sub_refs;
typedef struct _jc_soot_FastHierarchy__24Interval$sub_nonrefs	_jc_soot_FastHierarchy__24Interval$sub_nonrefs;
typedef struct _jc_soot_FastHierarchy__24Interval$refs	_jc_soot_FastHierarchy__24Interval$refs;
typedef struct _jc_soot_FastHierarchy__24Interval$nonrefs	_jc_soot_FastHierarchy__24Interval$nonrefs;
typedef struct _jc_soot_FastHierarchy__24Interval$object	_jc_soot_FastHierarchy__24Interval$object;

typedef const struct _jc_soot_FastHierarchy__24Interval$vmethods	_jc_soot_FastHierarchy__24Interval$vmethods;
typedef const struct _jc_soot_FastHierarchy__24Interval$vtable	_jc_soot_FastHierarchy__24Interval$vtable;
typedef const struct _jc_soot_FastHierarchy__24Interval$vtype	_jc_soot_FastHierarchy__24Interval$vtype;

// Constructors
extern void _jc_soot_FastHierarchy__24Interval$method$_init$fb49abce25a6a131(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy$object *);

// Virtual methods
extern jboolean _jc_soot_FastHierarchy__24Interval$method$isSubrange$68891e3e2f1f66bc(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy__24Interval$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_FastHierarchy__24Interval$method_info$isSubrange$68891e3e2f1f66bc;

// Virtual methods structure
struct _jc_soot_FastHierarchy__24Interval$vmethods {
	jboolean	(*isSubrange$68891e3e2f1f66bc)(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy__24Interval$object *);
};

// Vtable
struct _jc_soot_FastHierarchy__24Interval$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_FastHierarchy__24Interval$vmethods	soot_FastHierarchy__24Interval;
};

// Vtype
struct _jc_soot_FastHierarchy__24Interval$vtype {
	_jc_type			type;
	_jc_soot_FastHierarchy__24Interval$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_FastHierarchy__24Interval$sub_refs {
	struct _jc_soot_FastHierarchy$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_FastHierarchy__24Interval$refs {
    _jc_soot_FastHierarchy__24Interval$sub_refs	soot_FastHierarchy__24Interval;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_FastHierarchy__24Interval$sub_nonrefs {
	jint	lower;
	jint	upper;
};

// Non-reference instance fields (object)
struct _jc_soot_FastHierarchy__24Interval$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_FastHierarchy__24Interval$sub_nonrefs	soot_FastHierarchy__24Interval;
};

// Object instance structure
struct _jc_soot_FastHierarchy__24Interval$object {
	_jc_soot_FastHierarchy__24Interval$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_FastHierarchy__24Interval$vtype	*vtype;
	_jc_soot_FastHierarchy__24Interval$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_FastHierarchy__24Interval$vtype _jc_soot_FastHierarchy__24Interval$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_FastHierarchy__24Interval, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_FastHierarchy__24Interval$class_object;

#endif	/* _JC_soot_FastHierarchy__24Interval_H_ */

==> jc-1.4.6.tar.gz: soot/FastHierarchy__24Interval.h <==
// public class soot.FastHierarchy$Interval

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f9bd31f9535d22c1 soot_FastHierarchy__24Interval

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_FastHierarchy__24Interval_H_
#define _JC_soot_FastHierarchy__24Interval_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_FastHierarchy$object;
struct _jc_soot_FastHierarchy__24Interval$object;

// Typedefs
typedef struct _jc_soot_FastHierarchy__24Interval$sub_refs	_jc_soot_FastHierarchy__24Interval$sub_refs;
typedef struct _jc_soot_FastHierarchy__24Interval$sub_nonrefs	_jc_soot_FastHierarchy__24Interval$sub_nonrefs;
typedef struct _jc_soot_FastHierarchy__24Interval$refs	_jc_soot_FastHierarchy__24Interval$refs;
typedef struct _jc_soot_FastHierarchy__24Interval$nonrefs	_jc_soot_FastHierarchy__24Interval$nonrefs;
typedef struct _jc_soot_FastHierarchy__24Interval$object	_jc_soot_FastHierarchy__24Interval$object;

typedef const struct _jc_soot_FastHierarchy__24Interval$vmethods	_jc_soot_FastHierarchy__24Interval$vmethods;
typedef const struct _jc_soot_FastHierarchy__24Interval$vtable	_jc_soot_FastHierarchy__24Interval$vtable;
typedef const struct _jc_soot_FastHierarchy__24Interval$vtype	_jc_soot_FastHierarchy__24Interval$vtype;

// Constructors
extern void _jc_soot_FastHierarchy__24Interval$method$_init$fb49abce25a6a131(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_FastHierarchy__24Interval$method$isSubrange$68891e3e2f1f66bc(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy__24Interval$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_FastHierarchy__24Interval$method_info$isSubrange$68891e3e2f1f66bc;

// Virtual methods structure
struct _jc_soot_FastHierarchy__24Interval$vmethods {
	jboolean	(*isSubrange$68891e3e2f1f66bc)(_jc_env *, struct _jc_soot_FastHierarchy__24Interval$object *, struct _jc_soot_FastHierarchy__24Interval$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_FastHierarchy__24Interval$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_FastHierarchy__24Interval$vmethods	soot_FastHierarchy__24Interval;
};

// Vtype
struct _jc_soot_FastHierarchy__24Interval$vtype {
	_jc_type			type;
	_jc_soot_FastHierarchy__24Interval$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_FastHierarchy__24Interval$sub_refs {
	struct _jc_soot_FastHierarchy$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_FastHierarchy__24Interval$refs {
    _jc_soot_FastHierarchy__24Interval$sub_refs	soot_FastHierarchy__24Interval;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_FastHierarchy__24Interval$sub_nonrefs {
	jint	lower;
	jint	upper;
};

// Non-reference instance fields (object)
struct _jc_soot_FastHierarchy__24Interval$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_FastHierarchy__24Interval$sub_nonrefs	soot_FastHierarchy__24Interval;
};

// Object instance structure
struct _jc_soot_FastHierarchy__24Interval$object {
	_jc_soot_FastHierarchy__24Interval$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_FastHierarchy__24Interval$vtype	*vtype;
	_jc_soot_FastHierarchy__24Interval$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_FastHierarchy__24Interval$vtype _jc_soot_FastHierarchy__24Interval$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_FastHierarchy__24Interval, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_FastHierarchy__24Interval$class_object;

#endif	/* _JC_soot_FastHierarchy__24Interval_H_ */
